# Display Group

Display group commands are used to select a subset of the entities displayed in the viewport.

## Create display groups

```{eval-rst}
.. autoclass:: abaqus.DisplayGroup.DisplayGroupSession.DisplayGroupSession
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

```

## Other Classes

```{eval-rst}

.. toggle::

    .. autoclass:: abaqus.DisplayGroup.DisplayGroup.DisplayGroup
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.DisplayGroup.DisplayGroupArray.DisplayGroupArray
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.DisplayGroup.DisplayGroupInstance.DisplayGroupInstance
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.DisplayGroup.DisplayGroupInstanceRepository.DisplayGroupInstanceRepository
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.DisplayGroup.Leaf.Leaf
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.DisplayGroup.LeafFromDatums.LeafFromDatums
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.DisplayGroup.LeafFromDisplayGroup.LeafFromDisplayGroup
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.DisplayGroup.LeafFromElementLabels.LeafFromElementLabels
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.DisplayGroup.LeafFromElementSets.LeafFromElementSets
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.DisplayGroup.LeafFromElementVarRange.LeafFromElementVarRange
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.DisplayGroup.LeafFromGeometry.LeafFromGeometry
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.DisplayGroup.LeafFromInstance.LeafFromInstance
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.DisplayGroup.LeafFromInstanceElementLabels.LeafFromInstanceElementLabels
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.DisplayGroup.LeafFromInstanceNodeLabels.LeafFromInstanceNodeLabels
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.DisplayGroup.LeafFromMeshElementLabels.LeafFromMeshElementLabels
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.DisplayGroup.LeafFromMeshNodeLabels.LeafFromMeshNodeLabels
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.DisplayGroup.LeafFromMeshSurfaceSets.LeafFromMeshSurfaceSets
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.DisplayGroup.LeafFromModelElemLabels.LeafFromModelElemLabels
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.DisplayGroup.LeafFromModelNodeLabels.LeafFromModelNodeLabels
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.DisplayGroup.LeafFromNodeLabels.LeafFromNodeLabels
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.DisplayGroup.LeafFromNodeSets.LeafFromNodeSets
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.DisplayGroup.LeafFromNodeVarRange.LeafFromNodeVarRange
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.DisplayGroup.LeafFromOdbEdgePick.LeafFromOdbEdgePick
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.DisplayGroup.LeafFromOdbElementLayups.LeafFromOdbElementLayups
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.DisplayGroup.LeafFromOdbElementMaterials.LeafFromOdbElementMaterials
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.DisplayGroup.LeafFromOdbElementPick.LeafFromOdbElementPick
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.DisplayGroup.LeafFromOdbElementPlies.LeafFromOdbElementPlies
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.DisplayGroup.LeafFromOdbElementSections.LeafFromOdbElementSections
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.DisplayGroup.LeafFromOdbElementTypes.LeafFromOdbElementTypes
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.DisplayGroup.LeafFromOdbNodePick.LeafFromOdbNodePick
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.DisplayGroup.LeafFromPartElementLabels.LeafFromPartElementLabels
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.DisplayGroup.LeafFromPartInstance.LeafFromPartInstance
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.DisplayGroup.LeafFromPartNodeLabels.LeafFromPartNodeLabels
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.DisplayGroup.LeafFromReferencePoint.LeafFromReferencePoint
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.DisplayGroup.LeafFromSets.LeafFromSets
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.DisplayGroup.LeafFromSurfaceSets.LeafFromSurfaceSets
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.DisplayGroup.LeafFromSurfaceVarRange.LeafFromSurfaceVarRange
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::
```
